// RIBBON.CPP
// A generic OWL window with a toolbar
// (C) Copyright 1992 by Michael D. Most
// ObjectWindows - (C) Copyright 1991 by Borland International

#include "owl.h"

#define APPNAME "RIBBON"

#define IDM_ABOUT	101
#define IDM_EXIT	102


// Declare TApp, a TApplication descendant
class TApp : public TApplication {

public:
    TApp(LPSTR AName, HANDLE hInstance, HANDLE hPrevInstance,
      LPSTR lpCmdLine, int nCmdShow)
      : TApplication(AName, hInstance, hPrevInstance, lpCmdLine, nCmdShow) {};
    virtual void InitMainWindow();
};

// Declare TMyWindow, a TWindow descendant
class TMyWindow : public TWindow {
public:
    TMyWindow(PTWindowsObject, LPSTR);
    virtual void SetupWindow();
    void About(RTMessage) = [CM_FIRST + IDM_ABOUT];
    void Exit(RTMessage) = [CM_FIRST + IDM_EXIT];
};


// Declare TRibbonDialog, a TDialog descendent
class TRibbonDialog : public TDialog {
public:
    TRibbonDialog(PTWindowsObject AParent, LPSTR AName);
    virtual LPSTR GetClassName();
    virtual void WMControlColor(TMessage& Msg)
				= [WM_FIRST + WM_CTLCOLOR];
    virtual void WMPaint(TMessage& Msg)
			 = [WM_FIRST + WM_PAINT];
    void WMSize(TMessage& Msg)
			= [WM_FIRST + WM_SIZE];
};



// Construct a TMyWindow, loading its menu
TMyWindow::TMyWindow(PTWindowsObject AParent, LPSTR ATitle)
  : TWindow(AParent, ATitle)
{
   AssignMenu(APPNAME);
}


// Create ribbon bar as modeless dialog
void TMyWindow::SetupWindow()
{
   GetApplication()->MakeWindow(new TRibbonDialog(this, "RIBBON"));
}


void TMyWindow::About(RTMessage)
{
   GetApplication()->ExecDialog(new TDialog(this, "ABOUT_BOX"));
}


void TMyWindow::Exit(RTMessage)
{
   PostQuitMessage(0);
}



TRibbonDialog::TRibbonDialog(PTWindowsObject AParent, LPSTR AName):
		TDialog(AParent, AName)
{
}


// Get class name for modeless dialog from rc definition
LPSTR TRibbonDialog::GetClassName()
{
  return APPNAME;
}


// Create light gray background for ribbon bar
void TRibbonDialog::WMControlColor(TMessage& Msg)
{
  if (Msg.LP.Hi == CTLCOLOR_DLG)
   {
     SetBkMode(Msg.WParam, TRANSPARENT);
     Msg.Result = GetStockObject(LTGRAY_BRUSH);
   }
}


// Draw highlighting on top and bottom of ribbon bar for 3D look
void TRibbonDialog::WMPaint(TMessage& Msg)
{
  HPEN OldPen, DkGrayPen;
  RECT R;
  PAINTSTRUCT PS;

  BeginPaint(HWindow, &PS);
  OldPen = SelectObject(PS.hdc, GetStockObject(WHITE_PEN));
  MoveTo(PS.hdc, 0,0);
  GetClientRect(HWindow, &R);
  LineTo(PS.hdc, R.right, R.top);
  DkGrayPen = CreatePen(PS_SOLID, 1, RGB(72, 72, 72));
  SelectObject(PS.hdc, DkGrayPen);
  MoveTo(PS.hdc, R.left, R.bottom - 1);
  LineTo(PS.hdc, R.right, R.bottom - 1);
  SelectObject(PS.hdc, OldPen);
  DeleteObject(DkGrayPen);
  EndPaint(HWindow, &PS);
}


void TRibbonDialog::WMSize(TMessage& Msg)
{
  HWND hParent;
  RECT r;

  hParent = GetParent(HWindow);
  GetClientRect(hParent, &r);
  MoveWindow(HWindow, -1, -1, (r.right - r.left + 2),
	      (r.bottom - r.top + 1), TRUE);
}



// Construct the TApp's MainWindow of type TMyWindow
void TApp::InitMainWindow()
{
  MainWindow = new TMyWindow(NULL, "Ribbon Bar Test");
}


// Run the App
int PASCAL WinMain(HANDLE hInstance, HANDLE hPrevInstance,
  LPSTR lpCmdLine, int nCmdShow)
{
    TApp App ("App", hInstance, hPrevInstance,
      lpCmdLine, nCmdShow);
    App.Run();
    return App.Status;
}
